git

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package git provides some simple utility functions for working with git.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clone

func Clone(url, authToken string) (string, error)

Clone clones a repository to a temporary directory and returns the path to the cloned repository. The caller is responsible for cleaning up the repository when it is no longer needed.

Types

This section is empty.

Jump to